---
title: 네이버페이(주문형) 빠른 정산 이용안내
category: 결제서비스 (채널설정 및 이용안내) > 이용안내 > 결제대행사 계약
seo:
  title: 네이버페이(주문형) 빠른 정산 이용안내
  description: >-
    빠른 정산은 구매확정까지 기다림 없이 집화 처리 다음날 100% 지급되는 무료로 이용 가능한 정산 서비스입니다. 기존의 네이버페이 주문형
    이용 가맹점이나 유지 기준을 충족하시면 빠른 정산의 지속 적용이 가능합니다.
  keywords:
    - 네이버페이(주문형)
tags:
  - 네이버페이(주문형)
  - 결제대행사 계약
pgCompanies:
  - 네이버페이(주문형)
searchTags:
  - 주문형
  - 주문형 빠른정산
  - 네이버페이주문형
  - 네이버페이정산
  - 빠른정산
datetime: 2024-01-25T15:00:00.000Z
---

<Callout content="빠른 정산이란?
구매확정까지 기다림 없이 집화 처리 다음날 100% 지급되는 무료로 이용 가능한 정산 서비스입니다." title="" />

### **신청 기준**

- 네이버페이 주문형 이용 사업자
- 신청 기준을 충족한 사업자가 1회 신청 하게 되면, 그 이후부터는 유지 조건이 충족되는 한 빠른 정산 지속 적용
- 네이버페이 주문형을 미사용하는 사업자는 주문형 가입 후 신청 조건이 되었을 때 신청 가능합니다.



<Callout title="네이버페이센터로 신청하러가기 ↗" />
